section.Rdsection uses the LP1 function to generate a tibble of all the sections legnths representing 1 day of growth.
section(L, L.asym, k, Time = 1)
| L | numeric; the starting length of the sample |
|---|---|
| k | numeric; growth coefficient, calculate using the function k |
| Time | numeric; period of growth to be represented by each section. Default is 1 day. |
| L.asym. | numeric; asymptotic length |